#
# spec file for package kup-backup
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define rname kup
%bcond_without lang
Name:           kup-backup
Version:        0.9.1
Release:        2.11
Summary:        Backup scheduler for the Plasma desktop
License:        GPL-2.0-only AND GPL-3.0-only
Group:          System/GUI/KDE
URL:            https://apps.kde.org/kup/
Source0:        https://download.kde.org/stable/%{rname}/%{rname}-%{version}.tar.xz
%if %{with lang}
Source1:        https://download.kde.org/stable/%{rname}/%{rname}-%{version}.tar.xz.sig
Source2:        %{rname}.keyring
%endif
BuildRequires:  extra-cmake-modules
BuildRequires:  libgit2-devel
BuildRequires:  cmake(KF5Config)
BuildRequires:  cmake(KF5CoreAddons)
BuildRequires:  cmake(KF5DBusAddons)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5IdleTime)
BuildRequires:  cmake(KF5Init)
BuildRequires:  cmake(KF5JobWidgets)
BuildRequires:  cmake(KF5KIO)
BuildRequires:  cmake(KF5Notifications)
BuildRequires:  cmake(KF5Plasma)
BuildRequires:  cmake(KF5Solid)
BuildRequires:  cmake(KF5WidgetsAddons)
BuildRequires:  cmake(Qt5Widgets) >= 5.11.0
Recommends:     bup
Recommends:     rsync

%description
Kup is created for helping people to keep up-to-date backups of their personal files.
Connecting a USB hard drive is the primary supported way to store files, but saving
files to a server over a network connection is also possible for advanced users.

When you plug in your external hard drive Kup will automatically start copying your
latest changes, but of course it will only do so if you have been active on your
computer for some number of hours since the last time you took a backup (and it can
of course ask you first, before copying anything). In general Kup tries to not
disturb you needlessly.

%lang_package

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf5 -d build
%cmake_build

%install
%kf5_makeinstall -C build
%if %{with lang}
%find_lang %{rname}
%endif

%files
%license LICENSES/*
%doc README.md
%{_kf5_appstreamdir}/*.xml
%{_kf5_bindir}/kup-daemon
%{_kf5_bindir}/kup-filedigger
%{_kf5_bindir}/kup-purger
%{_kf5_configdir}/autostart/kup-daemon.desktop
%{_kf5_debugdir}/kup.categories
%{_kf5_iconsdir}/hicolor/scalable/apps/kup.svg
%{_kf5_libdir}/libkdeinit5_kup-daemon.so
%{_kf5_notifydir}/kupdaemon.notifyrc
%{_kf5_plugindir}/kcm_kup.so
%{_kf5_plugindir}/kio_bup.so
%{_kf5_plugindir}/plasma/
%{_kf5_sharedir}/plasma/
%{_kf5_servicesdir}

%if %{with lang}
%files lang -f %{rname}.lang
%license LICENSES/*
%endif

%changelog
* Tue Oct 11 2022 Olivier Belleux <o.g.m.belleux@gmail.com>
- update URL to https://apps.kde.org/kup/
* Sat Jun  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 0.9.1
  * Fix build with Qt 5.12
  * Bugfix for unintentional start of kup-purger (kde#438078)
- Drop upstream patch Fix-build-with-Qt-5.12.patch
* Thu May 27 2021 Wolfgang Bauer <wbauer@tmo.at>
- Update to 0.9.0
  * Added detection of when a source folder has been removed.
    Aborts saving backup and prompts user to review what should be
    included.
  * Added a way to prune old backup snapshots, with new small app
    kup-purger.
  * Bug: fix for detecting harmless errors from bup and ignoring
    them, bup version 0.31 had changed output format and this
    update follows that change.
  * Bug: fix detection of mount event for systemd automounts.
  * Bug: fix source selection tree view handling a selected source
    folder that has been removed.
  * Bug: fix source selection tree view when opening and selection
    is empty.
  * Bug: fix trying to open a file from a backup repo passed as a
    relative path as argument to kup-filedigger. (kde#425693)
  * New icon.
- Add Fix-build-with-Qt-5.12.patch to fix build on Leap 15.2/15.3
* Sat Sep 26 2020 Wolfgang Bauer <wbauer@tmo.at>
- Initial package
